@@ -632,7 +632,10 @@ def cal_performance(para_combination):
         # cov_return
         return_year_std = np.std(year_return_list)
         return_year_mean = np.mean(year_return_list)
-        cov_return = round(return_year_std / return_year_mean, 3)
+        if return_year_mean == 0:
+            cov_return = 0
+        else:
+            cov_return = round(return_year_std / return_year_mean, 3)
         result_dict['cov_return'] = cov_return
 
     result_dict['risk_free_rate'] = risk_free_rate
