@@ -296,16 +296,16 @@ class Components:
         per_col_2_1.append(html.Div('MDD Dollar'))
         per_col_2_1.append(html.Div('MDD Percentage'))
 
-        for i in range(7):
+        for i in range(8):
             per_col_1_2.append(html.Div(df[keys[i]], style={'text-align': 'center'}))
         try:
             per_col_1_2.append(html.Div( "{:.2%}".format(risk_free_rate / 100) , style={'text-align': 'center'}))
         except:
             per_col_1_2.append(html.Div('-----', style={'text-align': 'center'}))
 
-        for i in range(7, 13):
+        for i in range(8, 14):
             per_col_2_2.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
-        for i in range(13, 19):
+        for i in range(14, 20):
             per_col_2_3.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
 
         per_col1.append(dbc.Row([dbc.Col(html.Div(per_col_1_1), width=6),
@@ -516,6 +516,7 @@ class Components:
         df_profit = df_signal_list.loc[df_signal_list['action'] == 'profit_target']
         df_stop_loss = df_signal_list.loc[df_signal_list['action'] == 'stop_loss']
         df_close = df_signal_list.loc[df_signal_list['action'] == 'close_logic']
+        df_close = df_signal_list.loc[df_signal_list['action'] == 'close_logic']
 
         fig = go.Figure(data=[go.Candlestick(x=df['datetime'],
                                              open=df['open'],
@@ -590,21 +591,28 @@ class Components:
                 hovertemplate = hovertemplate + \
                                 key + " : " + str(graph_df.iloc[i][key]) + "<br>"
             hovertemplate = hovertemplate + "<br>"
-            hovertemplate = hovertemplate + "Return-BaH % Diff. : " + str(
-                round(graph_df.iloc[i]['return_to_bah'], 2)) + "<br>"
-            hovertemplate = hovertemplate + "Net Profit to MDD: " + str(
-                round(graph_df.iloc[i]['net_profit_to_mdd'], 2)) + "<br>"
-            hovertemplate = hovertemplate + "Sharp Ratio : " + str(graph_df.iloc[i]['annualized_sr']) + "<br>"
-            hovertemplate = hovertemplate + "MDD Percentage : " + "{:.0%}".format(
-                graph_df.iloc[i]['mdd_pct'] / 100) + "<br>"
+
             hovertemplate = hovertemplate + "Trade Count : " + str(graph_df.iloc[i]['num_of_trade']) + "<br>"
-            hovertemplate = hovertemplate + "COV (Count) : " + str(round(graph_df.iloc[i]['cov_count'], 2)) + "<br>"
-            hovertemplate = hovertemplate + "COV (Return) : " + str(round(graph_df.iloc[i]['cov_return'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "Net Profit : " + "{:,}".format(int(round(graph_df.iloc[i]['net_profit'], 0))) + "<br>"
+            hovertemplate = hovertemplate + "Net Profit to MDD: " + str(round(graph_df.iloc[i]['net_profit_to_mdd'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "Return-BaH % Diff. : " + "{:.0%}".format(float(graph_df.iloc[i]['return_to_bah']/100)) + "<br>"
             try:
-                hovertemplate = hovertemplate + "Win Rate : " + "{:.0%}".format(
-                    float(graph_df.iloc[i]['win_rate']) / 100) + "<br>"
+                hovertemplate = hovertemplate + "Win Rate : " + "{:.0%}".format(float(graph_df.iloc[i]['win_rate']) / 100) + "<br>"
             except:
                 hovertemplate = hovertemplate + "Win Rate : --" + "<br>"
+            hovertemplate = hovertemplate + "COV (Count) : " + str(round(graph_df.iloc[i]['cov_count'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "COV (Return) : " + str(round(graph_df.iloc[i]['cov_return'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "Total Commissionn : " + "{:,}".format(int(round(graph_df.iloc[i]['total_commission'], 2))) + "<br>"
+
+
+            hovertemplate = hovertemplate + "<br>"
+
+
+            hovertemplate = hovertemplate + "Return on Capital : " + "{:.0%}".format(graph_df.iloc[i]['return_on_capital']/100) + "<br>"
+            hovertemplate = hovertemplate + "Annual Return : " + "{:.0%}".format(graph_df.iloc[i]['annualized_return'] / 100) + "<br>"
+            hovertemplate = hovertemplate + "Sharp Ratio : " + str(graph_df.iloc[i]['annualized_sr']) + "<br>"
+            hovertemplate = hovertemplate + "MDD Percentage : " + "{:.0%}".format(graph_df.iloc[i]['mdd_pct'] / 100) + "<br>"
+
             hovertemplate = hovertemplate + "<br>"
 
             # para_combination for save_path generation
@@ -1327,7 +1335,10 @@ class Components:
                 year_return_list.append(0)
 
         cov_count = round(np.std(year_count) / np.mean(year_count), 2)
-        cov_return = round(np.std(year_return_list) / np.mean(year_return_list), 2)
+        if np.mean(year_return_list) == 0:
+            cov_return = 0
+        else:
+            cov_return = round(np.std(year_return_list) / np.mean(year_return_list), 2)
 
         div = html.Div([
 
